fnss.topologies.simplemodels.dumbbell_topology — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »

# fnss.topologies.simplemodels.dumbbell_topology

`dumbbell_topology`(m1, m2)

  Return a dumbbell topology consisting of two star topologies connected by a path.

  More precisely, two star graphs form the left and right bells, and are connected by a path .

  The nodes are numbered as follows.
    - for the left barbell,
    - for the path,
    - for the right barbell.

  The 3 subgraphs are joined via the edges and . If m2 = 0, this is merely two star topologies joined together.

  Please notice that this dumbbell topology is different from the barbell graph generated by networkx’s barbell_graph function. That barbell graph consists of two complete graphs connected by a path. This consists of two stars whose roots are connected by a path. This dumbbell topology is particularly useful for simulating transport layer protocols.

  All nodes and edges of this topology have an attribute type which can be either right bell, core or left_bell

  Parameters : | m1 : int The number of nodes in each bell m2 : int The number of nodes in the path
  Returns : | topology : A Topology object

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »